@@ -7,8 +7,15 @@ module LogStash
     module Commands
       class DefaultMetadata < Commands::Base
         def all
-          {:host => host, :version => version, :http_address => http_address,
-           :id => service.agent.id, :name => service.agent.name}
+          {:host => host,
+           :version => version,
+           :http_address => http_address,
+           :id => service.agent.id,
+           :name => service.agent.name,
+           :ephemeral_id => service.agent.ephemeral_id,
+           :status => "green",  # This is hard-coded to mirror x-pack behavior
+           :snapshot => ::BUILD_INFO["build_snapshot"],
+           }
         end
 
         def host
